@@ -5,10 +5,10 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 are_identical_alignments <- function(p, q) {
-  if (!is_alignment(p)) {
+  if (!beastier::is_alignment(p)) {
     stop("p must be an alignment")
   }
-  if (!is_alignment(q)) {
+  if (!beastier::is_alignment(q)) {
     stop("q must be an alignment")
   }
   return(identical(p, q))
